@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: css-text
 version: 0.1.2.1
-id: css-text-0.1.2.1-5f08c8634ff151127fcfba990f98863f
-key: csste_BKK1KtEb1sJ9s7LwxLpwLq
+id: css-text-0.1.2.1-fd7cfa8d457b06bb47b9d76e18d81e4c
+key: csste_DCmJgQlbndx5J1dp3gjSY0
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -18,9 +18,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/css-text-0.1.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/css-text-0.1.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/css-text-0.1.2.1
-hs-libraries: HScss-text-0.1.2.1-BKK1KtEb1sJ9s7LwxLpwLq
+hs-libraries: HScss-text-0.1.2.1-DCmJgQlbndx5J1dp3gjSY0
 depends:
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
